@@ -81,17 +81,23 @@ struct _MetaCompositorClass
   void              (* redraw)                       (MetaCompositor     *compositor);
 };
 
-gboolean     meta_compositor_set_selection      (MetaCompositor  *compositor,
-                                                 GError         **error);
+void         meta_compositor_set_composited          (MetaCompositor  *compositor,
+                                                      gboolean         composited);
 
-Window       meta_compositor_get_overlay_window (MetaCompositor  *compositor);
+gboolean     meta_compositor_check_common_extensions (MetaCompositor  *compositor,
+                                                      GError         **error);
 
-gboolean     meta_compositor_redirect_windows   (MetaCompositor  *compositor,
-                                                 GError         **error);
+gboolean     meta_compositor_set_selection           (MetaCompositor  *compositor,
+                                                      GError         **error);
 
-MetaDisplay *meta_compositor_get_display        (MetaCompositor  *compositor);
+Window       meta_compositor_get_overlay_window      (MetaCompositor  *compositor);
 
-void         meta_compositor_queue_redraw       (MetaCompositor  *compositor);
+gboolean     meta_compositor_redirect_windows        (MetaCompositor  *compositor,
+                                                      GError         **error);
+
+MetaDisplay *meta_compositor_get_display             (MetaCompositor  *compositor);
+
+void         meta_compositor_queue_redraw            (MetaCompositor  *compositor);
 
 G_END_DECLS
 
