@@ -1216,6 +1216,9 @@ meta_compositor_vulkan_manage (MetaCompositor  *compositor,
 
   vulkan = META_COMPOSITOR_VULKAN (compositor);
 
+  if (!meta_compositor_check_common_extensions (compositor, error))
+    return FALSE;
+
   enumerate_instance_layers (vulkan);
   enumerate_instance_extensions (vulkan);
 
@@ -1406,4 +1409,5 @@ meta_compositor_vulkan_class_init (MetaCompositorVulkanClass *vulkan_class)
 static void
 meta_compositor_vulkan_init (MetaCompositorVulkan *vulkan)
 {
+  meta_compositor_set_composited (META_COMPOSITOR (vulkan), TRUE);
 }
