@@ -1462,7 +1462,7 @@ paint_windows (MetaCompositorXRender *xrender,
           continue;
         }
 
-      if (!cw->window->mapped)
+      if (!meta_window_is_toplevel_mapped (cw->window))
         continue;
 
       if (cw->picture == None)
@@ -2355,7 +2355,13 @@ meta_compositor_xrender_finalize (GObject *object)
       int i;
 
       for (i = 0; i < LAST_SHADOW_TYPE; i++)
-        g_free (xrender->shadows[i]->gaussian_map);
+        {
+          g_clear_pointer (&xrender->shadows[i]->gaussian_map, g_free);
+          g_clear_pointer (&xrender->shadows[i]->shadow_corner, g_free);
+          g_clear_pointer (&xrender->shadows[i]->shadow_top, g_free);
+
+          g_clear_pointer (&xrender->shadows[i], g_free);
+        }
     }
 
   G_OBJECT_CLASS (meta_compositor_xrender_parent_class)->finalize (object);
@@ -2537,7 +2543,7 @@ meta_compositor_xrender_add_window (MetaCompositor *compositor,
   xrender->windows = g_list_prepend (xrender->windows, cw);
   g_hash_table_insert (xrender->windows_by_xid, (gpointer) xwindow, cw);
 
-  if (cw->window->mapped)
+  if (meta_window_is_toplevel_mapped (cw->window))
     map_win (xrender, cw);
 
   meta_error_trap_pop (display);
@@ -2856,26 +2862,12 @@ static void
 meta_compositor_xrender_maximize_window (MetaCompositor *compositor,
                                          MetaWindow     *window)
 {
-  MetaCompositorXRender *xrender = META_COMPOSITOR_XRENDER (compositor);
-  MetaCompWindow *cw = find_comp_window_by_window (xrender, window);
-
-  if (!cw)
-    return;
-
-  cw->needs_shadow = window_has_shadow (xrender, cw);
 }
 
 static void
 meta_compositor_xrender_unmaximize_window (MetaCompositor *compositor,
                                            MetaWindow     *window)
 {
-  MetaCompositorXRender *xrender = META_COMPOSITOR_XRENDER (compositor);
-  MetaCompWindow *cw = find_comp_window_by_window (xrender, window);
-
-  if (!cw)
-    return;
-
-  cw->needs_shadow = window_has_shadow (xrender, cw);
 }
 
 static void
@@ -2942,6 +2934,8 @@ meta_compositor_xrender_sync_window_geometry (MetaCompositor *compositor,
   if (cw == NULL)
     return;
 
+  cw->needs_shadow = window_has_shadow (xrender, cw);
+
   meta_error_trap_push (window->display);
 
   old_rect = cw->rect;
