@@ -33,6 +33,8 @@ typedef struct
 {
   MetaDisplay *display;
 
+  gboolean     composited;
+
   /* _NET_WM_CM_Sn */
   Atom         cm_atom;
   Window       cm_window;
@@ -54,6 +56,8 @@ enum
 
   PROP_DISPLAY,
 
+  PROP_COMPOSITED,
+
   LAST_PROP
 };
 
@@ -82,41 +86,6 @@ redraw_idle_cb (gpointer user_data)
   return G_SOURCE_REMOVE;
 }
 
-static gboolean
-check_common_extensions (MetaCompositor  *compositor,
-                         GError         **error)
-{
-  MetaCompositorPrivate *priv;
-
-  priv = meta_compositor_get_instance_private (compositor);
-
-  if (!priv->display->have_composite)
-    {
-      g_set_error (error, G_IO_ERROR, G_IO_ERROR_FAILED,
-                   "Missing composite extension required for compositing");
-
-      return FALSE;
-    }
-
-  if (!priv->display->have_damage)
-    {
-      g_set_error (error, G_IO_ERROR, G_IO_ERROR_FAILED,
-                   "Missing damage extension required for compositing");
-
-      return FALSE;
-    }
-
-  if (!priv->display->have_xfixes)
-    {
-      g_set_error (error, G_IO_ERROR, G_IO_ERROR_FAILED,
-                   "Missing xfixes extension required for compositing");
-
-      return FALSE;
-    }
-
-  return TRUE;
-}
-
 static gboolean
 meta_compositor_initable_init (GInitable     *initable,
                                GCancellable  *cancellable,
@@ -128,12 +97,6 @@ meta_compositor_initable_init (GInitable     *initable,
   compositor = META_COMPOSITOR (initable);
   compositor_class = META_COMPOSITOR_GET_CLASS (compositor);
 
-  if (!META_IS_COMPOSITOR_NONE (compositor))
-    {
-      if (!check_common_extensions (compositor, error))
-        return FALSE;
-    }
-
   return compositor_class->manage (compositor, error);
 }
 
@@ -212,6 +175,10 @@ meta_compositor_get_property (GObject    *object,
         g_value_set_pointer (value, priv->display);
         break;
 
+      case PROP_COMPOSITED:
+        g_value_set_boolean (value, priv->composited);
+        break;
+
       default:
         G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
         break;
@@ -236,6 +203,10 @@ meta_compositor_set_property (GObject      *object,
         priv->display = g_value_get_pointer (value);
         break;
 
+      case PROP_COMPOSITED:
+        g_assert_not_reached ();
+        break;
+
       default:
         G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
         break;
@@ -250,6 +221,11 @@ install_properties (GObjectClass *object_class)
                          G_PARAM_CONSTRUCT_ONLY | G_PARAM_READWRITE |
                          G_PARAM_STATIC_STRINGS);
 
+  properties[PROP_COMPOSITED] =
+    g_param_spec_boolean ("composited", "composited", "composited",
+                          FALSE,
+                          G_PARAM_READABLE | G_PARAM_STATIC_STRINGS);
+
   g_object_class_install_properties (object_class, LAST_PROP, properties);
 }
 
@@ -374,14 +350,25 @@ meta_compositor_window_opacity_changed (MetaCompositor *compositor,
 }
 
 void
-meta_compositor_window_shape_changed (MetaCompositor *compositor,
-                                      MetaWindow     *window)
+meta_compositor_window_opaque_region_changed (MetaCompositor *compositor,
+                                              MetaWindow     *window)
 {
   MetaCompositorClass *compositor_class;
 
   compositor_class = META_COMPOSITOR_GET_CLASS (compositor);
 
-  compositor_class->window_shape_changed (compositor, window);
+  compositor_class->window_opaque_region_changed (compositor, window);
+}
+
+void
+meta_compositor_window_shape_region_changed (MetaCompositor *compositor,
+                                             MetaWindow     *window)
+{
+  MetaCompositorClass *compositor_class;
+
+  compositor_class = META_COMPOSITOR_GET_CLASS (compositor);
+
+  compositor_class->window_shape_region_changed (compositor, window);
 }
 
 void
@@ -493,7 +480,62 @@ meta_compositor_is_our_xwindow (MetaCompositor *compositor,
 gboolean
 meta_compositor_is_composited (MetaCompositor *compositor)
 {
-  return !META_IS_COMPOSITOR_NONE (compositor);
+  MetaCompositorPrivate *priv;
+
+  priv = meta_compositor_get_instance_private (compositor);
+
+  return priv->composited;
+}
+
+void
+meta_compositor_set_composited (MetaCompositor *compositor,
+                                gboolean        composited)
+{
+  MetaCompositorPrivate *priv;
+
+  priv = meta_compositor_get_instance_private (compositor);
+
+  if (priv->composited == composited)
+    return;
+
+  priv->composited = composited;
+
+  g_object_notify_by_pspec (G_OBJECT (compositor), properties[PROP_COMPOSITED]);
+}
+
+gboolean
+meta_compositor_check_common_extensions (MetaCompositor  *compositor,
+                                         GError         **error)
+{
+  MetaCompositorPrivate *priv;
+
+  priv = meta_compositor_get_instance_private (compositor);
+
+  if (!priv->display->have_composite)
+    {
+      g_set_error (error, G_IO_ERROR, G_IO_ERROR_FAILED,
+                   "Missing composite extension required for compositing");
+
+      return FALSE;
+    }
+
+  if (!priv->display->have_damage)
+    {
+      g_set_error (error, G_IO_ERROR, G_IO_ERROR_FAILED,
+                   "Missing damage extension required for compositing");
+
+      return FALSE;
+    }
+
+  if (!priv->display->have_xfixes)
+    {
+      g_set_error (error, G_IO_ERROR, G_IO_ERROR_FAILED,
+                   "Missing xfixes extension required for compositing");
+
+      return FALSE;
+    }
+
+  return TRUE;
 }
 
 gboolean
