@@ -100,6 +100,7 @@ set_supported_hint (MetaScreen *screen)
 #undef EWMH_ATOMS_ONLY
 
     screen->display->atom__GTK_FRAME_EXTENTS,
+    screen->display->atom__GTK_SHOW_WINDOW_MENU
   };
 
   XChangeProperty (screen->display->xdisplay, screen->xroot,
@@ -275,7 +276,6 @@ meta_screen_new (MetaDisplay *display,
   char buf[128];
   guint32 manager_timestamp;
   gulong current_workspace;
-  gboolean composited;
 
   replace_current_wm = meta_get_replace_current_wm ();
 
@@ -514,8 +514,7 @@ meta_screen_new (MetaDisplay *display,
   screen->keys_grabbed = FALSE;
   meta_screen_grab_keys (screen);
 
-  composited = meta_compositor_is_composited (screen->display->compositor);
-  screen->ui = meta_ui_new (screen->display->xdisplay, composited);
+  screen->ui = meta_ui_new (screen->display->xdisplay, FALSE);
 
   screen->tab_popup = NULL;
   screen->tile_preview = NULL;
@@ -2411,7 +2410,7 @@ remove_sequence (MetaScreen        *screen,
 typedef struct
 {
   GSList *list;
-  GTimeVal now;
+  gint64  now;
 } CollectTimedOutData;
 
 /* This should be fairly long, as it should never be required unless
@@ -2432,9 +2431,7 @@ collect_timed_out_foreach (void *element,
 
   sn_startup_sequence_get_last_active_time (sequence, &tv_sec, &tv_usec);
 
-  elapsed =
-    ((((double)ctod->now.tv_sec - tv_sec) * G_USEC_PER_SEC +
-      (ctod->now.tv_usec - tv_usec))) / 1000.0;
+  elapsed = (ctod->now - (tv_sec * G_USEC_PER_SEC + tv_usec)) / 1000.0;
 
   meta_topic (META_DEBUG_STARTUP,
               "Sequence used %g seconds vs. %g max: %s\n",
@@ -2453,7 +2450,7 @@ startup_sequence_timeout (void *data)
   GSList *tmp;
 
   ctod.list = NULL;
-  g_get_current_time (&ctod.now);
+  ctod.now = g_get_real_time ();
   g_slist_foreach (screen->startup_sequences,
                    collect_timed_out_foreach,
                    &ctod);
