@@ -99,8 +99,11 @@ struct _MetaWindow
   MetaScreen *screen;
   MetaWorkspace *workspace;
   Window xwindow;
+
   /* may be NULL! not all windows get decorated */
   MetaFrame *frame;
+  guint reframe_id;
+
   int depth;
   Visual *xvisual;
   Colormap colormap;
@@ -356,7 +359,7 @@ struct _MetaWindow
   /* XSync update counter */
   XSyncCounter sync_request_counter;
   guint sync_request_serial;
-  GTimeVal sync_request_time;
+  gint64 sync_request_time;
   /* alarm monitoring client's _NET_WM_SYNC_REQUEST_COUNTER */
   XSyncAlarm sync_request_alarm;
 
@@ -601,7 +604,7 @@ unsigned long meta_window_get_net_wm_desktop (MetaWindow *window);
 
 void meta_window_show_menu (MetaWindow         *window,
                             const GdkRectangle *rect,
-                            const GdkEvent     *event);
+                            guint32             timestamp);
 
 gboolean meta_window_titlebar_is_onscreen    (MetaWindow *window);
 void     meta_window_shove_titlebar_onscreen (MetaWindow *window);
@@ -718,6 +721,8 @@ gboolean meta_window_updates_are_frozen (MetaWindow *window);
 
 void meta_window_update_shape_region (MetaWindow *window);
 
+void meta_window_reframe (MetaWindow *window);
+
 G_END_DECLS
 
 #endif
